@@ -69,36 +69,34 @@ test_that("insert_vectors chunks long text silently", {
   dbDisconnect(con, shutdown = TRUE)
 })
 
-test_that("build_vector_index succeeds silently with FTS", {
-
-  # 1. open an in-memory store (vss disabled for CRAN)
-  con <- create_vectorstore(
-    db_path       = ":memory:",
-    embedding_dim = 1536,
-    load_vss      = FALSE
-  )
-
-  insert_vectors(con, data.frame(page_content = "y"), mock_embed)
-
-  # 2. try to load FTS — skip gracefully if unavailable
+test_that("build_vector_index succeeds silently (vss/fts)", {
+  # Check whether FTS can load
   has_fts <- TRUE
+  tmp <- dbConnect(duckdb::duckdb(), ":memory:")
   tryCatch(
-    duckdb::duckdb_load_extension(con, "fts"),
-    error = function(e) has_fts <<- FALSE
+    dbExecute(tmp, "INSTALL fts; LOAD fts;"),
+    error = function(e) {
+      message("FTS not available: ", conditionMessage(e))
+      has_fts <<- FALSE
+    }
   )
+  dbDisconnect(tmp, shutdown = TRUE)
+
   if (!has_fts) {
-    dbDisconnect(con, shutdown = TRUE)
-    skip("DuckDB FTS extension not available on this platform.")
+    skip("Skipping FTS test: DuckDB FTS extension not available on this platform.")
   }
 
-  # 3. build the FTS index only
+  con <- suppressWarnings(create_vectorstore(":memory:", TRUE, 1536))
+  insert_vectors(con, data.frame(page_content = "y"), mock_embed)
+
   expect_silent(
-    suppressWarnings(build_vector_index(con, type = "fts"))
+    suppressWarnings(build_vector_index(con, c("vss", "fts")))
   )
 
   dbDisconnect(con, shutdown = TRUE)
 })
 
+
 test_that("dummy embeddings round-trip silently", {
   con <- suppressWarnings(create_vectorstore(":memory:", TRUE, 1536))
   expect_silent(
